UHFQA
=====

.. autoclass:: zhinst.qcodes.UHFQA
    :show-inheritance:
    :members:


AWG Core for UHFQA
------------------

.. autoclass:: zhinst.qcodes.uhfqa.AWG
    :show-inheritance:
    :members:



Readout Channel for UHFQA
-------------------------

.. autoclass:: zhinst.qcodes.uhfqa.Channel
    :show-inheritance:
    :members:
